@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "icmcomp"
 #include "icmcomp.ih"
 
+    // by run.cc
+
 int IcmComp::compile(string const &src, string const &dest)
 {
     return d_execute.run("icm-comp " + src + ' ' + dest, d_type);
