@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "icmcomp"
 #include "icmcomp.ih"
 
+    // by handler/compile.cc, sourcescript/compile.cc
+
 IcmComp::IcmComp(OptBase &optBase, Base::ExecType type, bool skipCompile)
 :
     d_preCompOpts(dynamic_cast<PreCompOpts &>(optBase)),
