@@ -1,10 +1,12 @@
-#define XERR
+#define XERR "scriptopts"
 #include "scriptopts.ih"
 
+    // by addimandbim.cc
+
 char *ScriptOpts::imName()
 {
                                             // construct the .im source
-    d_imFile = new TempStream{ tmpDir() };  // always a Temp. File
+    d_imFile = new TempStream{ tmp() };     // always a Temp. File
 
     ifstream script{ Exception::factory<ifstream>(d_orgArgs[2]) };
 
