@@ -1,10 +1,9 @@
 #define XERR
 #include "classes.ih"
 
-void Classes::subdirs(string const &list)
+void Classes::subdirs()
 {
-    Vect ignore;
-    String::split(&ignore, list);
+    StrVect const &ignore = d_options.ignore();
 
     for (char const *dirname: Glob{ Glob::DIRECTORY, "*", Glob::NOMATCH })
     {
