@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "dependencies"
 #include "dependencies.ih"
 
     // called from modules/modules.f
