@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "dependencies"
 #include "dependencies.ih"
 
 void Dependencies::show() const
