@@ -5,6 +5,7 @@ ModData::ModData(string const &modName, Type type, Path const &source)
 :
     d_type(type),
     d_source(source),
-    d_modName(modName)
+    d_modName(modName),
+    d_objStruct(0)
 {}
 
