@@ -6,8 +6,13 @@
 #include <mutex>
 #include <atomic>
 
-#include "../../tmp/build/fork/fork"
-#include "../../tmp/build/pipe/pipe"
+#ifdef fbb
+    #include <bobcat/fork>
+    #include <bobcat/pipe>
+#else
+    #include "../../tmp/build/fork/fork"
+    #include "../../tmp/build/pipe/pipe"
+#endif
 
 #include "../data/data.h"
 
