@@ -2,4 +2,4 @@
 #include "options.ih"
 
 Pattern Options::s_spec{ R"_([<"][^">]+[">])_" };
-Pattern Options::s_keep;
+Pattern Options::s_unused;
