@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "options"
 #include "options.ih"
 
 #include <sstream>
@@ -19,10 +19,6 @@ Options::Options()
     // with -a 'spch' is arg[0] and 'tmp/spch.gch' is arg[1]
 
     internalOpt();
-
-    ignored('g', "12.04.00");
-    ignored('r', "12.04.00");
-
     unusedOpt();
 
     if (not allOpt())
